==> haskell-distributive-0.6.2.1-273-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 distributive
version:              0.6.2.1
visibility:           public
id:                   distributive-0.6.2.1-IAn2fsllA095WMf59wtcuj
key:                  distributive-0.6.2.1-IAn2fsllA095WMf59wtcuj
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/distributive/
synopsis:             Distributive functors -- Dual to Traversable
description:          Distributive functors -- Dual to @Traversable@
category:             Data Structures
abi:                  dee81e3502957c874d2662e80a2f29f7
exposed:              True
exposed-modules:      Data.Distributive Data.Distributive.Generic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/distributive-0.6.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/distributive-0.6.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/distributive-0.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-distributive
hs-libraries:         HSdistributive-0.6.2.1-IAn2fsllA095WMf59wtcuj
depends:
    base-4.17.2.1 base-orphans-0.9.2-48glnjOLoSm9kmkjUSR7d
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-distributive/html/distributive.haddock

haddock-html:         /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-distributive-0.6.2.1-275-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 distributive
version:              0.6.2.1
visibility:           public
id:                   distributive-0.6.2.1-202InOOCyaJ6mKu3oixMmU
key:                  distributive-0.6.2.1-202InOOCyaJ6mKu3oixMmU
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/distributive/
synopsis:             Distributive functors -- Dual to Traversable
description:          Distributive functors -- Dual to @Traversable@
category:             Data Structures
abi:                  1b1bef592ef665018e5f8e62be75b5c5
exposed:              True
exposed-modules:      Data.Distributive Data.Distributive.Generic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/distributive-0.6.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/distributive-0.6.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/distributive-0.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-distributive
hs-libraries:         HSdistributive-0.6.2.1-202InOOCyaJ6mKu3oixMmU
depends:
    base-4.17.2.1 base-orphans-0.9.2-Ixj4mU4kWUSFy41vv9xgcX
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-distributive/html/distributive.haddock

haddock-html:         /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
